## Summary

<!-- Brief description of what this PR does and why -->

## Checklist

- [ ] Tests pass (`hatch run test`)
- [ ] Linting passes (`hatch run lint`)
- [ ] Type checking passes (`hatch run typecheck`)
- [ ] Code formatted (`hatch run format -- --check`)
- [ ] Conventional commit messages used (`feat:`, `fix:`, `docs:`, etc.)
